import { Directive, ElementRef, Input } from '@angular/core';
import { parse } from 'marked';
import { highlightBlock } from 'highlight.js';
var MarkdownDirective = (function () {
    function MarkdownDirective(el) {
        this.el = el;
        this.highlight = true;
        this.lineNumbers = true;
    }
    MarkdownDirective.prototype.ngOnInit = function () {
        this.el.nativeElement.innerHTML = parse(this.markdown, { sanitize: this.sanitize });
        if (this.highlight) {
            var preTags = this.el.nativeElement.getElementsByTagName('pre');
            for (var _i = 0, preTags_1 = preTags; _i < preTags_1.length; _i++) {
                var pre = preTags_1[_i];
                pre.classList.add(pre.getElementsByTagName('code')[0].className.split('-')[1]);
                this.removeLines(pre);
                highlightBlock(pre);
                if (this.lineNumbers) {
                    this.addLines(pre);
                }
            }
        }
    };
    MarkdownDirective.prototype.removeLines = function (pre) {
        var span = pre.querySelector('span.line-number');
        if (span) {
            pre.removeChild(span);
        }
    };
    MarkdownDirective.prototype.addLines = function (pre) {
        var style = 'style="float: left;text-align: right;"';
        var rowStyle = 'style="display: block;padding: 0 .5em 0 1em;border-right: 1px solid;margin-right: 5px;"';
        pre.innerHTML = '<span class="line-number" ' + style + '></span>' + pre.innerHTML + '<span class="cl"></span>';
        var num = pre.innerHTML.split(/\n/).length;
        for (var j = 1; j < num; j++) {
            var lineNum = pre.getElementsByTagName('span')[0];
            lineNum.innerHTML += '<span ' + rowStyle + '>' + (j) + '</span>';
        }
    };
    MarkdownDirective.decorators = [
        { type: Directive, args: [{ selector: '[markdown]' },] },
    ];
    /** @nocollapse */
    MarkdownDirective.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    MarkdownDirective.propDecorators = {
        'markdown': [{ type: Input },],
        'sanitize': [{ type: Input },],
        'highlight': [{ type: Input },],
        'lineNumbers': [{ type: Input },],
    };
    return MarkdownDirective;
}());
export { MarkdownDirective };
//# sourceMappingURL=markdown.directive.js.map